---
title: <span class="badge object-type-scalar"></span> Bool
---
# <span class="badge object-type-scalar"></span> Bool

Boolean: True / False

## Definition

```python
# Boolean: True / False
Bool: typing.Literal["bool"] = "bool"
```
